@@ -81,7 +81,8 @@ class BBoxFeature(tensor_feature.Tensor):
       if bbox.shape != (4,):
         raise ValueError(
             'array representing BBox should have exactly 4 floats. '
-            f'Instead, it has {bbox.shape}.')
+            f'Instead, it has {bbox.shape}.'
+        )
       bbox = bbox.astype(np.float64)
       bbox = BBox(ymin=bbox[0], xmin=bbox[1], ymax=bbox[2], xmax=bbox[3])
 
@@ -89,16 +90,20 @@ class BBoxFeature(tensor_feature.Tensor):
     for coordinate in bbox:
       if not isinstance(coordinate, float):
         raise ValueError(
-            'BBox coordinates should be float. Got {}.'.format(bbox))
+            'BBox coordinates should be float. Got {}.'.format(bbox)
+        )
       if not 0.0 <= coordinate <= 1.0:
         raise ValueError(
-            'BBox coordinates should be between 0 and 1. Got {}.'.format(bbox))
+            'BBox coordinates should be between 0 and 1. Got {}.'.format(bbox)
+        )
       if bbox.xmax < bbox.xmin or bbox.ymax < bbox.ymin:
         raise ValueError(
-            'BBox coordinates should have min <= max. Got {}.'.format(bbox))
+            'BBox coordinates should have min <= max. Got {}.'.format(bbox)
+        )
 
     return super(BBoxFeature, self).encode_example(
-        [bbox.ymin, bbox.xmin, bbox.ymax, bbox.xmax])
+        [bbox.ymin, bbox.xmin, bbox.ymax, bbox.xmax]
+    )
 
   def repr_html(self, ex: np.ndarray) -> str:
     """Returns the HTML str representation of an Image with BBoxes."""
@@ -111,11 +116,12 @@ class BBoxFeature(tensor_feature.Tensor):
 
   @classmethod
   def from_json_content(
-      cls, value: Union[Json, feature_pb2.BoundingBoxFeature]) -> 'BBoxFeature':
+      cls, value: Union[Json, feature_pb2.BoundingBoxFeature]
+  ) -> 'BBoxFeature':
     del value  # Unused
     return cls()
 
-  def to_json_content(self) -> feature_pb2.BoundingBoxFeature:
+  def to_json_content(self) -> feature_pb2.BoundingBoxFeature:  # pytype: disable=signature-mismatch  # overriding-return-type-checks
     return feature_pb2.BoundingBoxFeature(
         shape=feature_lib.to_shape_proto(self._shape),
         dtype=feature_lib.dtype_to_str(self._dtype),
