@@ -109,8 +109,10 @@ class Dataset(sequence_feature.Sequence):
     tensor_info = super().get_serialized_info()
     return tree_utils.map_structure(_add_dataset_lvl, tensor_info)
 
-  def encode_example(self, example_ds: Union[Iterator[type_utils.TreeDict[Any]],
-                                             Dict[str, Any]]):
+  def encode_example(
+      self,
+      example_ds: Union[Iterator[type_utils.TreeDict[Any]], Dict[str, Any]],
+  ):
     if isinstance(example_ds, dict):
       dict_list = sequence_feature.transpose_dict_list(example_ds)
     else:
@@ -122,8 +124,9 @@ class Dataset(sequence_feature.Sequence):
 
     # Empty datasets return empty arrays
     if not ds_elements:
-      return tree_utils.map_structure(sequence_feature.build_empty_np,
-                                      self.get_serialized_info())
+      return tree_utils.map_structure(
+          sequence_feature.build_empty_np, self.get_serialized_info()
+      )
 
     # Then convert back list[nested dict] => nested dict[list]
     encoded = sequence_feature.stack_nested(ds_elements)
@@ -139,7 +142,8 @@ class Dataset(sequence_feature.Sequence):
     if decoders:
       decode_fn = functools.partial(decode_fn, decoders=decoders)
     ds = tf.data.Dataset.from_tensor_slices(serialized_example).map(
-        decode_fn, num_parallel_calls=tf.data.experimental.AUTOTUNE)
+        decode_fn, num_parallel_calls=tf.data.experimental.AUTOTUNE
+    )
     return ds
 
   def _flatten(self, x):
