@@ -45,7 +45,8 @@ class VideoFeatureTest(testing.FeatureExpectationsTestCase):
                 expected=np_video,
             ),
         ],
-        test_attributes=dict(_encoding_format='png', _extra_ffmpeg_args=[]))
+        test_attributes=dict(_encoding_format='png', _extra_ffmpeg_args=[]),
+    )
 
   def test_video_concatenated_frames(self):
     video_shape = (None, 400, 640, 3)
