@@ -36,14 +36,17 @@ from tensorflow_datasets.core.utils.lazy_imports_utils import tensorflow as tf
 
 
 class ReadOnlyBuilder(
-    dataset_builder.FileReaderBuilder, skip_registration=True):
+    dataset_builder.FileReaderBuilder, skip_registration=True
+):
   """Generic DatasetBuilder loading from a directory."""
 
   @tfds_logging.builder_init()
-  def __init__(self,
-               builder_dir: epath.PathLike,
-               *,
-               info_proto: Optional[dataset_info_pb2.DatasetInfo] = None):
+  def __init__(
+      self,
+      builder_dir: epath.PathLike,
+      *,
+      info_proto: Optional[dataset_info_pb2.DatasetInfo] = None,
+  ):
     """Constructor.
 
     Args:
@@ -85,7 +88,8 @@ class ReadOnlyBuilder(
     if self.info.features is None:
       raise ValueError(
           f'Cannot restore {self.info.full_name}. It likely means the dataset '
-          'was generated with an old TFDS version (<=3.2.1).')
+          'was generated with an old TFDS version (<=3.2.1).'
+      )
 
   def _create_builder_config(
       self, builder_config: Optional[dataset_builder.BuilderConfig]
@@ -104,11 +108,12 @@ class ReadOnlyBuilder(
   def _download_and_prepare(self, **kwargs):  # pylint: disable=arguments-differ
     # DatasetBuilder.download_and_prepare is a no-op as self.data_dir already
     # exists.
-    raise AssertionError('ReadOnlyBuilder can\'t be generated.')
+    raise AssertionError("ReadOnlyBuilder can't be generated.")
 
 
 def builder_from_directory(
-    builder_dir: epath.PathLike,) -> dataset_builder.DatasetBuilder:
+    builder_dir: epath.PathLike,
+) -> dataset_builder.DatasetBuilder:
   """Loads a `tfds.core.DatasetBuilder` from the given generated dataset path.
 
   Reconstructs the `tfds.core.DatasetBuilder` without requiring the original
@@ -164,7 +169,8 @@ def builder_from_directories(
     raise ValueError('No builder dirs were given!')
 
   dataset_infos = utils.tree.parallel_map(
-      dataset_info.read_proto_from_builder_dir, {d: d for d in builder_dirs})
+      dataset_info.read_proto_from_builder_dir, {d: d for d in builder_dirs}
+  )
 
   # TODO(tfds): assert that the features of all datasets are identical.
 
@@ -172,29 +178,34 @@ def builder_from_directories(
     filename_template = naming.ShardedFileTemplate(
         dataset_name=dataset_info_proto.name,
         data_dir=builder_dir,
-        filetype_suffix=dataset_info_proto.file_format or filetype_suffix)
+        filetype_suffix=dataset_info_proto.file_format or filetype_suffix,
+    )
     return splits_lib.SplitDict.from_proto(
         repeated_split_infos=dataset_info_proto.splits,
-        filename_template=filename_template)
+        filename_template=filename_template,
+    )
 
-  merged_split_dict = splits_lib.SplitDict.merge_multiple([
-      get_split_dict(builder_dir, dataset_info_proto)
-      for builder_dir, dataset_info_proto in dataset_infos.items()
-  ])
+  merged_split_dict = splits_lib.SplitDict.merge_multiple(
+      [
+          get_split_dict(builder_dir, dataset_info_proto)
+          for builder_dir, dataset_info_proto in dataset_infos.items()
+      ]
+  )
 
   # We create the ReadOnlyBuilder for a random builder_dir and then update the
   # splits to capture the splits from all builder dirs.
   random_builder_dir = builder_dirs[0]
   random_builder = ReadOnlyBuilder(
       builder_dir=random_builder_dir,
-      info_proto=dataset_infos[random_builder_dir])
+      info_proto=dataset_infos[random_builder_dir],
+  )
   random_builder.info.set_splits(merged_split_dict)
   return random_builder
 
 
 def builder_from_metadata(
-    builder_dir: epath.PathLike,
-    info_proto: dataset_info_pb2.DatasetInfo) -> dataset_builder.DatasetBuilder:
+    builder_dir: epath.PathLike, info_proto: dataset_info_pb2.DatasetInfo
+) -> dataset_builder.DatasetBuilder:
   """Loads a `tfds.core.DatasetBuilder` from the given metadata.
 
   Reconstructs the `tfds.core.DatasetBuilder` without requiring the original
@@ -248,11 +259,13 @@ def builder_from_files(
   builder_dir = _find_builder_dir(name, **builder_kwargs)
   if builder_dir is None:
     data_dirs = file_utils.list_data_dirs(
-        given_data_dir=builder_kwargs.get('data_dir'))
+        given_data_dir=builder_kwargs.get('data_dir')
+    )
     raise registered.DatasetNotFoundError(
         f'Could not find dataset files for: {name}. Make sure the dataset '
         f'has been generated in: {data_dirs}. If the dataset has configs, you '
-        'might have to specify the config name.')
+        'might have to specify the config name.'
+    )
   return builder_from_directory(builder_dir)
 
 
@@ -278,7 +291,8 @@ def _find_builder_dir(name: str, **builder_kwargs: Any) -> Optional[str]:
   """
   # Normalize builder kwargs
   name, builder_kwargs = naming.parse_builder_name_kwargs(
-      name, **builder_kwargs)
+      name, **builder_kwargs
+  )
   version = builder_kwargs.pop('version', None)
   config = builder_kwargs.pop('config', None)
   data_dir = builder_kwargs.pop('data_dir', None)
@@ -288,8 +302,12 @@ def _find_builder_dir(name: str, **builder_kwargs: Any) -> Optional[str]:
   # * version='experimental_latest'
   # * config objects (rather than `str`)
   # * custom DatasetBuilder.__init__ kwargs
-  if (name.namespace or version == 'experimental_latest' or
-      isinstance(config, dataset_builder.BuilderConfig) or builder_kwargs):
+  if (
+      name.namespace
+      or version == 'experimental_latest'
+      or isinstance(config, dataset_builder.BuilderConfig)
+      or builder_kwargs
+  ):
     error_msgs = ['Builder cannot be loaded from files if it uses:']
     if name.namespace:
       error_msgs.append(f'* namespaces (here, {name.namespace} is used)')
@@ -334,7 +352,8 @@ def _find_builder_dir(name: str, **builder_kwargs: Any) -> Optional[str]:
     # ```
     raise ValueError(
         f'Dataset {name} detected in multiple locations: {all_builder_dirs}. '
-        'Please resolve the ambiguity by explicitly setting `data_dir=`.')
+        'Please resolve the ambiguity by explicitly setting `data_dir=`.'
+    )
 
   return all_builder_dirs[0]
 
@@ -371,11 +390,12 @@ def _find_builder_dir_single_dir(
   builder_dir = epath.Path(data_dir) / builder_name
 
   # If the version is specified, check if the dataset dir exists and return.
-  if (version_str and version_lib.Version.is_valid(version_str)):
+  if version_str and version_lib.Version.is_valid(version_str):
     dataset_dir = _get_dataset_dir(
         builder_dir=builder_dir,
         version_str=version_str,
-        config_name=config_name)
+        config_name=config_name,
+    )
     if _contains_dataset(dataset_dir):
       return os.fspath(dataset_dir)
 
@@ -383,29 +403,36 @@ def _find_builder_dir_single_dir(
   # config and load the dataset for that.
   if not config_name:
     default_config_name = _get_default_config_name(
-        builder_dir=builder_dir, name=builder_name)
+        builder_dir=builder_dir, name=builder_name
+    )
     if default_config_name:
       return _find_builder_dir_single_dir(
           builder_name=builder_name,
           data_dir=data_dir,
           config_name=default_config_name,
-          version_str=version_str)
+          version_str=version_str,
+      )
 
   # Dataset wasn't found, try to find a suitable available version.
   found_version_str = _get_version_str(
-      builder_dir, config_name=config_name, requested_version=version_str)
-  if (found_version_str and
-      (version_str is None or found_version_str != version_str)):
+      builder_dir, config_name=config_name, requested_version=version_str
+  )
+  if found_version_str and (
+      version_str is None or found_version_str != version_str
+  ):
     return _find_builder_dir_single_dir(
         builder_name=builder_name,
         data_dir=data_dir,
         config_name=config_name,
-        version_str=found_version_str)
+        version_str=found_version_str,
+    )
 
   # If no builder found, we populate the error_context with useful information
   # and return None.
-  error_utils.add_context(('No builder could be found in the directory: '
-                           f'{data_dir} for the builder: {builder_name}.'))
+  error_utils.add_context(
+      'No builder could be found in the directory: '
+      f'{data_dir} for the builder: {builder_name}.'
+  )
   return None
 
 
@@ -464,10 +491,13 @@ def _get_version_str(
       return str(v)
   # Directory doesn't have version, or requested_version doesn't match
   if requested_version:
-    error_msg = (f'No version matching the requested {requested_version} was '
-                 f'found in the builder directory: {builder_dir}.')
+    error_msg = (
+        f'No version matching the requested {requested_version} was '
+        f'found in the builder directory: {builder_dir}.'
+    )
   else:
-    error_msg = (f'The builder directory {builder_dir} doesn\'t contain any '
-                 'versions.')
+    error_msg = (
+        f"The builder directory {builder_dir} doesn't contain any versions."
+    )
   error_utils.add_context(error_msg)
   return None
