@@ -20,7 +20,6 @@ import itertools
 import os
 from unittest import mock
 
-import six
 import tensorflow as tf
 import tensorflow_datasets as tfds
 from tensorflow_datasets import testing
@@ -35,14 +34,18 @@ from tensorflow_datasets.core.utils import shard_utils
 # Skip the cardinality test for backward compatibility with TF <= 2.1.
 _SKIP_CARDINALITY_TEST = not hasattr(tf.data.experimental, 'assert_cardinality')
 
-_SHUFFLE_FILES_ERROR_MESSAGE = ('Dataset is an ordered dataset '
-                                '(\'disable_shuffling=True\'), but examples '
-                                'will not be read in order because '
-                                '`shuffle_files=True`.')
-_CYCLE_LENGTH_ERROR_MESSAGE = ('Dataset is an ordered dataset '
-                               '(\'disable_shuffling=True\'), but examples will'
-                               ' not be read in order because '
-                               '`ReadConfig.interleave_cycle_length != 1`.')
+_SHUFFLE_FILES_ERROR_MESSAGE = (
+    'Dataset is an ordered dataset '
+    "('disable_shuffling=True'), but examples "
+    'will not be read in order because '
+    '`shuffle_files=True`.'
+)
+_CYCLE_LENGTH_ERROR_MESSAGE = (
+    'Dataset is an ordered dataset '
+    "('disable_shuffling=True'), but examples will"
+    ' not be read in order because '
+    '`ReadConfig.interleave_cycle_length != 1`.'
+)
 
 
 def _write_tfrecord_from_shard_spec(shard_spec, get):
@@ -66,8 +69,9 @@ class ReaderTest(testing.TestCase):
 
   def setUp(self):
     super(ReaderTest, self).setUp()
-    with mock.patch.object(example_parser, 'ExampleParser',
-                           testing.DummyParser):
+    with mock.patch.object(
+        example_parser, 'ExampleParser', testing.DummyParser
+    ):
       self.reader = reader_lib.Reader(self.tmp_dir, 'some_spec')
       self.reader.read = functools.partial(
           self.reader.read,
@@ -80,7 +84,8 @@ class ReaderTest(testing.TestCase):
         dataset_name='mnist',
         split=split,
         filetype_suffix='tfrecord',
-        data_dir=self.tmp_dir)
+        data_dir=self.tmp_dir,
+    )
 
   def _write_tfrecord(self, split_name, shards_number, records):
     filename_template = self._filename_template(split=split_name)
@@ -90,21 +95,27 @@ class ReaderTest(testing.TestCase):
         total_size=0,
         bucket_lengths=[num_examples],
         filename_template=filename_template,
-        shard_config=shard_utils.ShardConfig(num_shards=shards_number))
-    serialized_records = [(key, six.b(rec)) for key, rec in enumerate(records)]
+        shard_config=shard_utils.ShardConfig(num_shards=shards_number),
+    )
+    serialized_records = [
+        (key, bytes(rec, encoding='utf-8')) for key, rec in enumerate(records)
+    ]
     for shard_spec in shard_specs:
-      _write_tfrecord_from_shard_spec(shard_spec,
-                                      lambda unused_i: iter(serialized_records))
+      _write_tfrecord_from_shard_spec(
+          shard_spec, lambda unused_i: iter(serialized_records)
+      )
     return splits.SplitInfo(
         name=split_name,
         shard_lengths=[int(s.examples_number) for s in shard_specs],
         num_bytes=0,
-        filename_template=filename_template)
+        filename_template=filename_template,
+    )
 
   def test_nodata_instruction(self):
     # Given instruction corresponds to no data.
-    with self.assertRaisesWithPredicateMatch(ValueError,
-                                             'corresponds to no data!'):
+    with self.assertRaisesWithPredicateMatch(
+        ValueError, 'corresponds to no data!'
+    ):
       train_info = splits.SplitInfo(
           name='train',
           shard_lengths=[2, 3, 2, 3, 2],
@@ -123,7 +134,9 @@ class ReaderTest(testing.TestCase):
         split_infos=[train_info],
     )
     read_data = list(tfds.as_numpy(ds))
-    self.assertEqual(read_data, [six.b(l) for l in 'abcdefghijkl'])
+    self.assertEqual(
+        read_data, [bytes(l, encoding='utf-8') for l in 'abcdefghijkl']
+    )
 
     if not _SKIP_CARDINALITY_TEST:
       # Check that the cardinality is correctly set.
@@ -136,7 +149,9 @@ class ReaderTest(testing.TestCase):
         split_infos=[train_info],
     )
     read_data = list(tfds.as_numpy(ds))
-    self.assertEqual(read_data, [six.b(l) for l in 'abcdefghijklab'])
+    self.assertEqual(
+        read_data, [bytes(l, encoding='utf-8') for l in 'abcdefghijklab']
+    )
 
     if not _SKIP_CARDINALITY_TEST:
       # Check that the cardinality is correctly set.
@@ -155,7 +170,9 @@ class ReaderTest(testing.TestCase):
         split_infos=split_info,
     )
     read_data = list(tfds.as_numpy(ds))
-    self.assertEqual(read_data, [six.b(l) for l in 'bcdefghijkmno'])
+    self.assertEqual(
+        read_data, [bytes(l, encoding='utf-8') for l in 'bcdefghijkmno']
+    )
 
     if not _SKIP_CARDINALITY_TEST:
       # Check that the cardinality is correctly set.
@@ -181,7 +198,9 @@ class ReaderTest(testing.TestCase):
 
   def test_shuffle_deterministic(self):
     split_info = self._write_tfrecord('train', 5, 'abcdefghijkl')
-    read_config = read_config_lib.ReadConfig(shuffle_seed=123,)
+    read_config = read_config_lib.ReadConfig(
+        shuffle_seed=123,
+    )
     ds = self.reader.read(
         instructions='train',
         split_infos=[split_info],
@@ -191,9 +210,23 @@ class ReaderTest(testing.TestCase):
     ds_values = list(tfds.as_numpy(ds))
 
     # Check that shuffle=True with a seed provides deterministic results.
-    self.assertEqual(ds_values, [
-        b'a', b'b', b'k', b'l', b'h', b'i', b'j', b'c', b'd', b'e', b'f', b'g'
-    ])
+    self.assertEqual(
+        ds_values,
+        [
+            b'a',
+            b'b',
+            b'k',
+            b'l',
+            b'h',
+            b'i',
+            b'j',
+            b'c',
+            b'd',
+            b'e',
+            b'f',
+            b'g',
+        ],
+    )
 
   def test_4fold(self):
     train_info = self._write_tfrecord('train', 5, 'abcdefghijkl')
@@ -205,22 +238,37 @@ class ReaderTest(testing.TestCase):
         instructions=instructions,
         split_infos=[train_info],
     )
-    instructions = [(splits.ReadInstruction('train', to=k, unit='%') +
-                     splits.ReadInstruction('train', from_=k + 25, unit='%'))
-                    for k in range(0, 100, 25)]
+    instructions = [
+        (
+            splits.ReadInstruction('train', to=k, unit='%')
+            + splits.ReadInstruction('train', from_=k + 25, unit='%')
+        )
+        for k in range(0, 100, 25)
+    ]
     trains = self.reader.read(
         instructions=instructions,
         split_infos=[train_info],
     )
     read_tests = [list(r) for r in tfds.as_numpy(tests)]
     read_trains = [list(r) for r in tfds.as_numpy(trains)]
-    self.assertEqual(read_tests, [[b'a', b'b', b'c'], [b'd', b'e', b'f'],
-                                  [b'g', b'h', b'i'], [b'j', b'k', b'l']])
-    self.assertEqual(read_trains,
-                     [[b'd', b'e', b'f', b'g', b'h', b'i', b'j', b'k', b'l'],
-                      [b'a', b'b', b'c', b'g', b'h', b'i', b'j', b'k', b'l'],
-                      [b'a', b'b', b'c', b'd', b'e', b'f', b'j', b'k', b'l'],
-                      [b'a', b'b', b'c', b'd', b'e', b'f', b'g', b'h', b'i']])
+    self.assertEqual(
+        read_tests,
+        [
+            [b'a', b'b', b'c'],
+            [b'd', b'e', b'f'],
+            [b'g', b'h', b'i'],
+            [b'j', b'k', b'l'],
+        ],
+    )
+    self.assertEqual(
+        read_trains,
+        [
+            [b'd', b'e', b'f', b'g', b'h', b'i', b'j', b'k', b'l'],
+            [b'a', b'b', b'c', b'g', b'h', b'i', b'j', b'k', b'l'],
+            [b'a', b'b', b'c', b'd', b'e', b'f', b'j', b'k', b'l'],
+            [b'a', b'b', b'c', b'd', b'e', b'f', b'g', b'h', b'i'],
+        ],
+    )
 
   def test_read_files(self):
     self._write_tfrecord('train', 4, 'abcdefghijkl')
@@ -230,23 +278,29 @@ class ReaderTest(testing.TestCase):
             shard_utils.FileInstruction(
                 filename=os.fspath(
                     filename_template.sharded_filepath(
-                        shard_index=1, num_shards=4)),
+                        shard_index=1, num_shards=4
+                    )
+                ),
                 skip=0,
                 take=-1,
-                num_examples=3),
+                examples_in_shard=3,
+            ),
             shard_utils.FileInstruction(
                 filename=os.fspath(
                     filename_template.sharded_filepath(
-                        shard_index=3, num_shards=4)),
+                        shard_index=3, num_shards=4
+                    )
+                ),
                 skip=1,
                 take=1,
-                num_examples=1),
+                examples_in_shard=3,
+            ),
         ],
         read_config=read_config_lib.ReadConfig(),
         shuffle_files=False,
     )
     read_data = list(tfds.as_numpy(ds))
-    self.assertEqual(read_data, [six.b(l) for l in 'defk'])
+    self.assertEqual(read_data, [bytes(l, encoding='utf-8') for l in 'defk'])
 
   def test_input_context(self):
     split_info = self._write_tfrecord('train', 5, 'abcdefghijkl')
@@ -262,15 +316,16 @@ class ReaderTest(testing.TestCase):
                       input_context=tf.distribute.InputContext(
                           num_input_pipelines=num_workers,
                           input_pipeline_id=index,
-                      ),),
+                      ),
+                  ),
                   # Workers should read a deterministic subset of the examples,
                   # even if examples within one worker may be shuffled.
                   shuffle_files=True,
-              )))
+              )
+          )
+      )
 
     def _b(bytes_str):
-      if six.PY2:
-        return list(bytes_str)
       # Convert to List[bytes] (rather than List[int])
       return [bytes([b]) for b in bytes_str]
 
@@ -289,17 +344,21 @@ class ReaderTest(testing.TestCase):
   def test_shuffle_files_should_be_disabled(self):
     self._write_tfrecord('train', 4, 'abcdefghijkl')
     filename_template = self._filename_template(split='train')
-    with self.assertRaisesWithPredicateMatch(ValueError,
-                                             _SHUFFLE_FILES_ERROR_MESSAGE):
+    with self.assertRaisesWithPredicateMatch(
+        ValueError, _SHUFFLE_FILES_ERROR_MESSAGE
+    ):
       self.reader.read_files(
           [
               shard_utils.FileInstruction(
                   filename=os.fspath(
                       filename_template.sharded_filepath(
-                          shard_index=1, num_shards=4)),
+                          shard_index=1, num_shards=4
+                      )
+                  ),
                   skip=0,
                   take=-1,
-                  num_examples=3),
+                  examples_in_shard=3,
+              ),
           ],
           read_config=read_config_lib.ReadConfig(),
           shuffle_files=True,
@@ -312,11 +371,12 @@ class ReaderTest(testing.TestCase):
     instructions = [
         shard_utils.FileInstruction(
             filename=os.fspath(
-                filename_template.sharded_filepath(shard_index=1,
-                                                   num_shards=4)),
+                filename_template.sharded_filepath(shard_index=1, num_shards=4)
+            ),
             skip=0,
             take=-1,
-            num_examples=3),
+            examples_in_shard=3,
+        ),
     ]
     # In ordered dataset interleave_cycle_length is set to 1 by default
     self.reader.read_files(
@@ -325,8 +385,9 @@ class ReaderTest(testing.TestCase):
         shuffle_files=False,
         disable_shuffling=True,
     )
-    with self.assertRaisesWithPredicateMatch(ValueError,
-                                             _CYCLE_LENGTH_ERROR_MESSAGE):
+    with self.assertRaisesWithPredicateMatch(
+        ValueError, _CYCLE_LENGTH_ERROR_MESSAGE
+    ):
       self.reader.read_files(
           instructions,
           read_config=read_config_lib.ReadConfig(interleave_cycle_length=16),
@@ -340,26 +401,32 @@ class ReaderTest(testing.TestCase):
     instructions = [
         shard_utils.FileInstruction(
             filename=filename_template.sharded_filepath(
-                shard_index=1, num_shards=4),
+                shard_index=1, num_shards=4
+            ),
             skip=0,
             take=-1,
-            num_examples=3),
+            examples_in_shard=3,
+        ),
     ]
     reported_warnings = []
     with mock.patch('absl.logging.warning', reported_warnings.append):
       self.reader.read_files(
           instructions,
           read_config=read_config_lib.ReadConfig(
-              interleave_cycle_length=16, enable_ordering_guard=False),
+              interleave_cycle_length=16, enable_ordering_guard=False
+          ),
           shuffle_files=True,
           disable_shuffling=True,
       )
-      expected_warning = _SHUFFLE_FILES_ERROR_MESSAGE + '\n' + _CYCLE_LENGTH_ERROR_MESSAGE
+      expected_warning = (
+          _SHUFFLE_FILES_ERROR_MESSAGE + '\n' + _CYCLE_LENGTH_ERROR_MESSAGE
+      )
       self.assertIn(expected_warning, reported_warnings)
 
   @mock.patch(
       'tensorflow.data.experimental.assert_cardinality',
-      wraps=tf.data.experimental.assert_cardinality)
+      wraps=tf.data.experimental.assert_cardinality,
+  )
   def test_assert_cardinality_is_on_by_default(self, assert_cardinality):
     train_info = self._write_tfrecord('train', 5, 'abcdefghijkl')
     self.reader.read(instructions='train', split_infos=[train_info])
@@ -367,12 +434,14 @@ class ReaderTest(testing.TestCase):
 
   @mock.patch('tensorflow.data.experimental.assert_cardinality')
   def test_assert_cardinality_can_be_disabled_through_readconfig(
-      self, assert_cardinality):
+      self, assert_cardinality
+  ):
     train_info = self._write_tfrecord('train', 5, 'abcdefghijkl')
     self.reader.read(
         instructions='train',
         split_infos=[train_info],
-        read_config=read_config_lib.ReadConfig(assert_cardinality=False))
+        read_config=read_config_lib.ReadConfig(assert_cardinality=False),
+    )
     assert not assert_cardinality.called
 
 
@@ -385,25 +454,27 @@ def test_shard_api():
           dataset_name='ds_name',
           split='train',
           filetype_suffix='tfrecord',
-          data_dir='/path'))
+          data_dir='/path',
+      ),
+  )
   fi = [
       shard_utils.FileInstruction(
           filename='/path/ds_name-train.tfrecord-00000-of-00003',
           skip=0,
           take=-1,
-          num_examples=10,
+          examples_in_shard=10,
       ),
       shard_utils.FileInstruction(
           filename='/path/ds_name-train.tfrecord-00001-of-00003',
           skip=0,
           take=-1,
-          num_examples=20,
+          examples_in_shard=20,
       ),
       shard_utils.FileInstruction(
           filename='/path/ds_name-train.tfrecord-00002-of-00003',
           skip=0,
           take=-1,
-          num_examples=13,
+          examples_in_shard=13,
       ),
   ]
   sd = splits.SplitDict([si])
