@@ -54,6 +54,9 @@ _ABSTRACT_DATASET_COLLECTION_REGISTRY = {}
 # Keep track of Dict[str (module name), List[DatasetCollectionBuilder]]
 _MODULE_TO_DATASET_COLLECTIONS = collections.defaultdict(list)
 
+# eg for dataset "foo": "tensorflow_datasets.datasets.foo.foo_dataset_builder".
+_BUILDER_MODULE_SUFFIX = '_dataset_builder'
+
 
 class DatasetNotFoundError(ValueError):
   """Exception raised when the dataset cannot be found."""
@@ -111,10 +114,12 @@ class RegisteredDatasetCollection(abc.ABC):
       pass
     elif cls.name in _DATASET_COLLECTION_REGISTRY:
       raise ValueError(
-          f'DatasetCollection with name {cls.name} already registered.')
+          f'DatasetCollection with name {cls.name} already registered.'
+      )
     elif cls.name in _ABSTRACT_DATASET_COLLECTION_REGISTRY:
       raise ValueError(
-          f'DatasetCollection with name {cls.name} already registered as abstract.'
+          f'DatasetCollection with name {cls.name} already registered as'
+          ' abstract.'
       )
 
     # Add the dataset_collection to the registers
@@ -127,8 +132,8 @@ class RegisteredDatasetCollection(abc.ABC):
 def list_imported_dataset_collections() -> List[str]:
   """Returns the string names of all `tfds.core.DatasetCollection`s."""
   all_dataset_collections = [
-      dataset_collection_name for dataset_collection_name,
-      dataset_collection_cls in _DATASET_COLLECTION_REGISTRY.items()
+      dataset_collection_name
+      for dataset_collection_name, dataset_collection_cls in _DATASET_COLLECTION_REGISTRY.items()
   ]
   return sorted(all_dataset_collections)
 
@@ -138,7 +143,8 @@ def is_dataset_collection(name: str) -> bool:
 
 
 def imported_dataset_collection_cls(
-    name: str) -> Type[RegisteredDatasetCollection]:
+    name: str,
+) -> Type[RegisteredDatasetCollection]:
   """Returns the Registered dataset class."""
   if name in _ABSTRACT_DATASET_COLLECTION_REGISTRY:
     raise AssertionError(f'DatasetCollection {name} is an abstract class.')
@@ -166,12 +172,19 @@ class RegisteredDataset(abc.ABC):
     if not cls.__dict__.get('name'):
       if cls.__name__ == 'Builder':
         # Config-based builders should be defined with a class named "Builder".
-        # In such a case, the builder name is extracted from the package name:
-        # 1 package = 1 dataset!.
-        module_path_components = cls.__module__.rsplit('.', 2)
-        if len(module_path_components) != 3:
-          raise AssertionError(f'module path is too short: {cls.__module__}')
-        cls.name = module_path_components[1]
+        # In such a case, the builder name is extracted from the module if it
+        # follows conventions:
+        module_name = cls.__module__.rsplit('.', 1)[-1]
+        if module_name.endswith(_BUILDER_MODULE_SUFFIX):
+          cls.name = module_name[: -len(_BUILDER_MODULE_SUFFIX)]
+        elif '.' in cls.__module__:  # Extract dataset name from package name.
+          cls.name = cls.__module__.rsplit('.', 2)[-2]
+        else:
+          raise AssertionError(
+              'When using `Builder` as class name, the dataset builder name is '
+              'inferred from module name if named "*_dataset_builder" or from '
+              f'package name, but there is no package in "{cls.__module__}".'
+          )
       else:  # Legacy builders.
         cls.name = naming.camelcase_to_snakecase(cls.__name__)
 
@@ -196,7 +209,8 @@ class RegisteredDataset(abc.ABC):
       raise ValueError(f'Dataset with name {cls.name} already registered.')
     elif cls.name in _ABSTRACT_DATASET_REGISTRY:
       raise ValueError(
-          f'Dataset with name {cls.name} already registered as abstract.')
+          f'Dataset with name {cls.name} already registered as abstract.'
+      )
 
     # Add the dataset to the registers
     if is_abstract:
@@ -213,7 +227,8 @@ def _is_builder_available(builder_cls: Type[RegisteredDataset]) -> bool:
 def list_imported_builders() -> List[str]:
   """Returns the string names of all `tfds.core.DatasetBuilder`s."""
   all_builders = [
-      builder_name for builder_name, builder_cls in _DATASET_REGISTRY.items()
+      builder_name
+      for builder_name, builder_cls in _DATASET_REGISTRY.items()
       if _is_builder_available(builder_cls)
   ] + list(_get_existing_dataset_packages(constants.DATASETS_TFDS_SRC_DIR))
   return sorted(all_builders)
@@ -221,7 +236,8 @@ def list_imported_builders() -> List[str]:
 
 @functools.lru_cache(maxsize=None)
 def _get_existing_dataset_packages(
-    datasets_dir: Text) -> Dict[Text, Tuple[epath.Path, Text]]:
+    datasets_dir: Text,
+) -> Dict[Text, Tuple[epath.Path, Text]]:
   """Returns existing datasets.
 
   Args:
@@ -243,8 +259,9 @@ def _get_existing_dataset_packages(
     return datasets
   if not datasets_dir_path.exists():
     return datasets
-  ds_dir_pkg = '.'.join(['tensorflow_datasets'] +
-                        datasets_dir.split(os.path.sep))
+  ds_dir_pkg = '.'.join(
+      ['tensorflow_datasets'] + datasets_dir.split(os.path.sep)
+  )
   for child in datasets_dir_path.iterdir():
     # Except for a few exceptions, all children of datasets/ directory are
     # packages of datasets, no needs to check child is a directory and contains
@@ -254,7 +271,9 @@ def _get_existing_dataset_packages(
     ]
     if child.name not in exceptions:
       pkg_path = epath.Path(datasets_dir_path) / child.name
-      builder_module = f'{ds_dir_pkg}.{child.name}.{child.name}_dataset_builder'
+      builder_module = (
+          f'{ds_dir_pkg}.{child.name}.{child.name}{_BUILDER_MODULE_SUFFIX}'
+      )
       datasets[child.name] = (pkg_path, builder_module)
   return datasets
 
@@ -262,7 +281,8 @@ def _get_existing_dataset_packages(
 def imported_builder_cls(name: str) -> Type[RegisteredDataset]:
   """Returns the Registered dataset class."""
   existing_ds_pkgs = _get_existing_dataset_packages(
-      constants.DATASETS_TFDS_SRC_DIR)
+      constants.DATASETS_TFDS_SRC_DIR
+  )
   if name in existing_ds_pkgs:
     pkg_dir_path, builder_module = existing_ds_pkgs[name]
     cls = importlib.import_module(builder_module).Builder
