@@ -55,6 +55,7 @@ class RawBenchmarkResult:
     batch_size: the number of examples in each iteration.
     durations_ns: the duration in ns of each iteration that was processed.
   """
+
   num_iter: int
   num_examples: int
   start_time: int
@@ -90,7 +91,8 @@ class RawBenchmarkResult:
     return [_ns_to_s(d) for d in self.durations_ns]
 
   def summary_statistics(
-      self, include_first: bool) -> Dict[str, Union[float, List[float]]]:
+      self, include_first: bool
+  ) -> Dict[str, Union[float, List[float]]]:
     if self.durations_ns is None:
       return {}
     durations = self.durations_s(include_first)
@@ -109,26 +111,37 @@ class RawBenchmarkResult:
         'num_iter': self.num_iter,
     }
     return pd.DataFrame.from_dict(
-        raw_stats, orient='index', columns=['duration'])
+        raw_stats, orient='index', columns=['duration']
+    )
 
   def stats(self) -> Dict[str, StatDict]:
     return {
-        'first+lasts':
-            _log_stats('First included', self.start_time, self.end_time,
-                       self.num_examples + self.batch_size),
-        'first':
-            _log_stats('First only', self.start_time, self.first_batch_time,
-                       self.batch_size),
-        'lasts':
-            _log_stats('First excluded', self.first_batch_time, self.end_time,
-                       self.num_examples)
+        'first+lasts': _log_stats(
+            'First included',
+            self.start_time,
+            self.end_time,
+            self.num_examples + self.batch_size,
+        ),
+        'first': _log_stats(
+            'First only',
+            self.start_time,
+            self.first_batch_time,
+            self.batch_size,
+        ),
+        'lasts': _log_stats(
+            'First excluded',
+            self.first_batch_time,
+            self.end_time,
+            self.num_examples,
+        ),
     }
 
   def stats_pd(self) -> pd.DataFrame:
     return pd.DataFrame.from_dict(self.stats(), orient='index')
 
   def __repr__(self) -> str:
-    return textwrap.dedent(f"""
+    return textwrap.dedent(
+        f"""
       BenchmarkResult(
         num_iter = {self.num_iter}
         num_examples = {self.num_examples}
@@ -136,7 +149,8 @@ class RawBenchmarkResult:
         examples / sec = {self.examples_per_second()}
         duration: {self.summary_statistics(include_first=True)}
         duration without first: {self.summary_statistics(include_first=False)}
-      )""")
+      )"""
+    )
 
 
 @dataclasses.dataclass(frozen=True)
@@ -202,7 +216,9 @@ def raw_benchmark(
   if num_iter and actual_num_iter < num_iter:
     logging.warning(
         'Number of iterations is shorter than expected ({} vs {})'.format(
-            actual_num_iter, num_iter))
+            actual_num_iter, num_iter
+        )
+    )
 
   durations_ns = []
   for i in range(len(results)):
@@ -218,7 +234,8 @@ def raw_benchmark(
       first_batch_time=first_batch_time,
       end_time=end_time,
       batch_size=batch_size,
-      durations_ns=durations_ns)
+      durations_ns=durations_ns,
+  )
 
 
 def benchmark(
@@ -264,9 +281,9 @@ def _log_stats(msg: str, start: int, end: int, num_examples: int) -> StatDict:
   """Log and returns stats."""
   if not num_examples:
     stats = {
-        'duration': 0.,
+        'duration': 0.0,
         'num_examples': 0,
-        'avg': 0.,
+        'avg': 0.0,
     }
   else:
     # Make sure the total time is not 0.
@@ -277,6 +294,8 @@ def _log_stats(msg: str, start: int, end: int, num_examples: int) -> StatDict:
         'num_examples': num_examples,
         'avg': num_examples / total_time_s,
     }
-  print('Examples/sec ({}) {avg:.2f} ex/sec (total: {num_examples} ex, '
-        '{duration:.2f} sec)'.format(msg, **stats))
+  print(
+      'Examples/sec ({}) {avg:.2f} ex/sec (total: {num_examples} ex, '
+      '{duration:.2f} sec)'.format(msg, **stats)
+  )
   return stats
