@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,7 +36,6 @@ class TqdmStream:
   for _ in tqdm.tqdm(range(10)):
     logger.info('No visual artifacts')
   ```
-
   """
 
   def write(self, x):
@@ -95,6 +94,23 @@ def async_tqdm(*args, **kwargs):
     return EmptyTqdm(*args, **kwargs)
 
 
+def display_progress_bar(enable: bool) -> None:
+  """Controls whether Tqdm progress bar is enabled/disabled.
+
+  Usage:
+
+  ```
+  tfds.display_progress_bar(enable=True)
+  ```
+
+  Args:
+    enable: whether to display the progress bar.
+  """
+  # Replace tqdm
+  global _active
+  _active = enable
+
+
 def disable_progress_bar():
   """Disables Tqdm progress bar.
 
@@ -103,7 +119,6 @@ def disable_progress_bar():
   ```
   tfds.disable_progress_bar()
   ```
-
   """
   # Replace tqdm
   global _active
@@ -118,7 +133,6 @@ def enable_progress_bar():
   ```
   tfds.enable_progress_bar()
   ```
-
   """
   # Replace tqdm
   global _active
@@ -153,6 +167,7 @@ def _async_tqdm(*args, **kwargs):
 
 class _TqdmPbarAsync(object):
   """Wrapper around Tqdm pbar which be shared between thread."""
+
   _tqdm_bars = []
 
   def __init__(self, pbar):
