@@ -24,15 +24,17 @@ import tensorflow_datasets.public_api as tfds
 class D4rlMujocoHopper(dataset_builder.D4RLDatasetBuilder):
   """DatasetBuilder for hopper dataset."""
 
-  VERSION = tfds.core.Version('1.1.0')
+  VERSION = tfds.core.Version('1.2.0')
   RELEASE_NOTES = {
       '1.0.0': 'Initial release.',
       '1.1.0': 'Added is_last.',
+      '1.2.0': 'Updated to take into account the next observation.',
   }
 
   BUILDER_CONFIGS = dataset_builder.MUJOCO_BUILDER_CONFIGS
 
   def __init__(self, **kwargs: Any):
     config = dataset_builder.DatasetConfig(
-        name='hopper', obs_len=11, action_len=3, qpos_len=6, qvel_len=6)
+        name='hopper', obs_len=11, action_len=3, qpos_len=6, qvel_len=6
+    )
     super().__init__(ds_config=config, **kwargs)
