@@ -19,9 +19,10 @@ import tensorflow_datasets.public_api as tfds
 
 
 class ImagenetV2Test(tfds.testing.DatasetBuilderTestCase):
-
   BUILDER_CONFIG_NAMES_TO_TEST = [
-      'matched-frequency', 'threshold-0.7', 'topimages'
+      'matched-frequency',
+      'threshold-0.7',
+      'topimages',
   ]
 
   DATASET_CLASS = imagenet_v2_dataset_builder.Builder
