@@ -25,10 +25,12 @@ _CMATERDB_IMAGE_SHAPE = (_CMATERDB_IMAGE_SIZE, _CMATERDB_IMAGE_SIZE, 3)
 # GitHub npz mirror of https://code.google.com/archive/p/cmaterdb/
 _CMATERDB_TRAINING_URL = (
     "https://raw.githubusercontent.com/prabhuomkar/CMATERdb/master/"
-    "datasets/{type}-numerals/training-images.npz")
+    "datasets/{type}-numerals/training-images.npz"
+)
 _CMATERDB_TESTING_URL = (
     "https://raw.githubusercontent.com/prabhuomkar/CMATERdb/master/"
-    "datasets/{type}-numerals/testing-images.npz")
+    "datasets/{type}-numerals/testing-images.npz"
+)
 
 _CITATION = """\
 @article{Das:2012:GAB:2161007.2161320,
