@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -41,16 +41,15 @@ class TFFlowers(tfds.core.GeneratorBasedBuilder):
         builder=self,
         description="A large set of images of flowers",
         features=tfds.features.FeaturesDict({
-            "image":
-                tfds.features.Image(),
-            "label":
-                tfds.features.ClassLabel(names=[
-                    "dandelion", "daisy", "tulips", "sunflowers", "roses"
-                ]),
+            "image": tfds.features.Image(),
+            "label": tfds.features.ClassLabel(
+                names=["dandelion", "daisy", "tulips", "sunflowers", "roses"]
+            ),
         }),
         supervised_keys=("image", "label"),
         homepage="https://www.tensorflow.org/tutorials/load_data/images",
-        citation=_CITATION)
+        citation=_CITATION,
+    )
 
   def _split_generators(self, dl_manager):
     path = dl_manager.download(_URL)
@@ -59,7 +58,8 @@ class TFFlowers(tfds.core.GeneratorBasedBuilder):
     return [
         tfds.core.SplitGenerator(
             name=tfds.Split.TRAIN,
-            gen_kwargs={"images_dir_path": dl_manager.iter_archive(path)}),
+            gen_kwargs={"images_dir_path": dl_manager.iter_archive(path)},
+        ),
     ]
 
   def _generate_examples(self, images_dir_path):
