@@ -15,11 +15,6 @@
 
 """Public API of tfds, without the registered dataset."""
 
-# pylint: disable=unused-import,g-import-not-at-top,g-bad-import-order,wrong-import-position
-from tensorflow_datasets.core import tf_compat
-
-tf_compat.ensure_tf_install()
-
 from tensorflow_datasets import core
 from tensorflow_datasets import typing
 from tensorflow_datasets.core import beam_utils as beam
@@ -29,6 +24,7 @@ from tensorflow_datasets.core import deprecated
 from tensorflow_datasets.core import download
 from tensorflow_datasets.core import features
 from tensorflow_datasets.core import folder_dataset
+from tensorflow_datasets.core import transform  # pylint: disable=unused-import
 from tensorflow_datasets.core import visualization
 from tensorflow_datasets.core.as_dataframe import as_dataframe
 from tensorflow_datasets.core.dataset_utils import as_numpy
@@ -37,31 +33,31 @@ from tensorflow_datasets.core.folder_dataset import ImageFolder
 from tensorflow_datasets.core.folder_dataset import TranslateFolder
 from tensorflow_datasets.core.load import builder
 from tensorflow_datasets.core.load import builder_cls
+from tensorflow_datasets.core.load import dataset_collection
 from tensorflow_datasets.core.load import list_builders
 from tensorflow_datasets.core.load import list_dataset_collections
 from tensorflow_datasets.core.load import load
-from tensorflow_datasets.core.load import dataset_collection
-from tensorflow_datasets.core.read_only_builder import builder_from_directory
 from tensorflow_datasets.core.read_only_builder import builder_from_directories
+from tensorflow_datasets.core.read_only_builder import builder_from_directory
 from tensorflow_datasets.core.splits import Split
-from tensorflow_datasets.core.subsplits_utils import split_for_jax_process
 from tensorflow_datasets.core.subsplits_utils import even_splits
+from tensorflow_datasets.core.subsplits_utils import split_for_jax_process
 from tensorflow_datasets.core.utils.benchmark import benchmark
 from tensorflow_datasets.core.utils.gcs_utils import is_dataset_on_gcs
+from tensorflow_datasets.core.utils.lazy_imports_utils import lazy_imports
 from tensorflow_datasets.core.utils.read_config import ReadConfig
 from tensorflow_datasets.core.utils.tqdm_utils import disable_progress_bar
-from tensorflow_datasets.core.utils.tqdm_utils import enable_progress_bar
 from tensorflow_datasets.core.utils.tqdm_utils import display_progress_bar
+from tensorflow_datasets.core.utils.tqdm_utils import enable_progress_bar
 from tensorflow_datasets.core.visualization import show_examples
 from tensorflow_datasets.core.visualization import show_statistics
 from tensorflow_datasets.version import __version__
 
 deprecated = core.utils.docs.deprecated(deprecated)
 
-with core.registered.skip_registration():
-  # We import testing namespace but without registering the tests datasets
-  # (e.g. DummyMnist,...).
-  from tensorflow_datasets import testing
+with lazy_imports():
+  from tensorflow_datasets import testing  # pylint: disable=g-import-not-at-top
+del lazy_imports
 
 __all__ = [
     "as_dataframe",
