@@ -53,14 +53,19 @@ _CITATION = """
 """
 
 _TASK_NAMES = [
-    'humanoid_corridor', 'humanoid_gaps', 'humanoid_walls',
-    'rodent_bowl_escape', 'rodent_gaps', 'rodent_mazes', 'rodent_two_touch'
+    'humanoid_corridor',
+    'humanoid_gaps',
+    'humanoid_walls',
+    'rodent_bowl_escape',
+    'rodent_gaps',
+    'rodent_mazes',
+    'rodent_two_touch',
 ]
 
 
 def _sequence(
-    shape_size: Optional[int] = None,
-    dtype: Optional[tf.DType] = None) -> tf.io.FixedLenSequenceFeature:
+    shape_size: Optional[int] = None, dtype: Optional[tf.DType] = None
+) -> tf.io.FixedLenSequenceFeature:
   if dtype is None:
     dtype = tf.float32
   if shape_size:
@@ -74,73 +79,45 @@ def _feature_description(task_name: str) -> Dict[str, Any]:
   """Returns the shape of a tf.Example for the given task."""
   if 'humanoid' in task_name:
     return {
-        'observation/walker/joints_vel':
-            _sequence(56),
-        'observation/walker/sensors_velocimeter':
-            _sequence(3),
-        'observation/walker/sensors_gyro':
-            _sequence(3),
-        'observation/walker/joints_pos':
-            _sequence(56),
-        'observation/walker/world_zaxis':
-            _sequence(3),
-        'observation/walker/body_height':
-            _sequence(1),
-        'observation/walker/sensors_accelerometer':
-            _sequence(3),
-        'observation/walker/end_effectors_pos':
-            _sequence(12),
-        'observation/walker/egocentric_camera':
-            _sequence(shape_size=None, dtype=tf.string),
-        'action':
-            _sequence(56),
-        'discount':
-            _sequence(),
-        'reward':
-            _sequence(),
-        'step_type':
-            _sequence(),
-        'episode_id':
-            tf.io.FixedLenFeature([], tf.int64),
-        'timestamp':
-            tf.io.FixedLenFeature([], tf.int64)
+        'observation/walker/joints_vel': _sequence(56),
+        'observation/walker/sensors_velocimeter': _sequence(3),
+        'observation/walker/sensors_gyro': _sequence(3),
+        'observation/walker/joints_pos': _sequence(56),
+        'observation/walker/world_zaxis': _sequence(3),
+        'observation/walker/body_height': _sequence(1),
+        'observation/walker/sensors_accelerometer': _sequence(3),
+        'observation/walker/end_effectors_pos': _sequence(12),
+        'observation/walker/egocentric_camera': _sequence(
+            shape_size=None, dtype=tf.string
+        ),
+        'action': _sequence(56),
+        'discount': _sequence(),
+        'reward': _sequence(),
+        'step_type': _sequence(),
+        'episode_id': tf.io.FixedLenFeature([], tf.int64),
+        'timestamp': tf.io.FixedLenFeature([], tf.int64),
     }
   else:
     return {
-        'observation/walker/joints_pos':
-            _sequence(30),
-        'observation/walker/joints_vel':
-            _sequence(30),
-        'observation/walker/tendons_pos':
-            _sequence(8),
-        'observation/walker/tendons_vel':
-            _sequence(8),
-        'observation/walker/appendages_pos':
-            _sequence(15),
-        'observation/walker/world_zaxis':
-            _sequence(3),
-        'observation/walker/sensors_accelerometer':
-            _sequence(3),
-        'observation/walker/sensors_velocimeter':
-            _sequence(3),
-        'observation/walker/sensors_gyro':
-            _sequence(3),
-        'observation/walker/sensors_touch':
-            _sequence(4),
-        'observation/walker/egocentric_camera':
-            _sequence(shape_size=None, dtype=tf.string),
-        'action':
-            _sequence(38),
-        'discount':
-            _sequence(),
-        'reward':
-            _sequence(),
-        'step_type':
-            _sequence(),
-        'episode_id':
-            tf.io.FixedLenFeature([], tf.int64),
-        'timestamp':
-            tf.io.FixedLenFeature([], tf.int64)
+        'observation/walker/joints_pos': _sequence(30),
+        'observation/walker/joints_vel': _sequence(30),
+        'observation/walker/tendons_pos': _sequence(8),
+        'observation/walker/tendons_vel': _sequence(8),
+        'observation/walker/appendages_pos': _sequence(15),
+        'observation/walker/world_zaxis': _sequence(3),
+        'observation/walker/sensors_accelerometer': _sequence(3),
+        'observation/walker/sensors_velocimeter': _sequence(3),
+        'observation/walker/sensors_gyro': _sequence(3),
+        'observation/walker/sensors_touch': _sequence(4),
+        'observation/walker/egocentric_camera': _sequence(
+            shape_size=None, dtype=tf.string
+        ),
+        'action': _sequence(38),
+        'discount': _sequence(),
+        'reward': _sequence(),
+        'step_type': _sequence(),
+        'episode_id': tf.io.FixedLenFeature([], tf.int64),
+        'timestamp': tf.io.FixedLenFeature([], tf.int64),
     }
 
 
@@ -162,72 +139,51 @@ class RluLocomotion(rlu_common.RLUBuilder):
   def get_features_dict(self):
     if 'humanoid' in self.builder_config.name:
       walker_features = {
-          'joints_vel':
-              rlu_common.float_tensor_feature(56),
-          'sensors_velocimeter':
-              rlu_common.float_tensor_feature(3),
-          'sensors_gyro':
-              rlu_common.float_tensor_feature(3),
-          'joints_pos':
-              rlu_common.float_tensor_feature(56),
-          'world_zaxis':
-              rlu_common.float_tensor_feature(3),
-          'body_height':
-              rlu_common.float_tensor_feature(1),
-          'sensors_accelerometer':
-              rlu_common.float_tensor_feature(3),
-          'end_effectors_pos':
-              rlu_common.float_tensor_feature(12),
-          'egocentric_camera':
-              tfds.features.Image(
-                  shape=(64, 64, 3), dtype=np.uint8, encoding_format='png'),
+          'joints_vel': rlu_common.float_tensor_feature(56),
+          'sensors_velocimeter': rlu_common.float_tensor_feature(3),
+          'sensors_gyro': rlu_common.float_tensor_feature(3),
+          'joints_pos': rlu_common.float_tensor_feature(56),
+          'world_zaxis': rlu_common.float_tensor_feature(3),
+          'body_height': rlu_common.float_tensor_feature(1),
+          'sensors_accelerometer': rlu_common.float_tensor_feature(3),
+          'end_effectors_pos': rlu_common.float_tensor_feature(12),
+          'egocentric_camera': tfds.features.Image(
+              shape=(64, 64, 3), dtype=np.uint8, encoding_format='png'
+          ),
       }
       action_features = tfds.features.Tensor(shape=(56,), dtype=np.float32)
     else:  # 'rodent' datasets
       walker_features = {
-          'joints_pos':
-              rlu_common.float_tensor_feature(30),
-          'joints_vel':
-              rlu_common.float_tensor_feature(30),
-          'tendons_pos':
-              rlu_common.float_tensor_feature(8),
-          'tendons_vel':
-              rlu_common.float_tensor_feature(8),
-          'appendages_pos':
-              rlu_common.float_tensor_feature(15),
-          'world_zaxis':
-              rlu_common.float_tensor_feature(3),
-          'sensors_accelerometer':
-              rlu_common.float_tensor_feature(3),
-          'sensors_velocimeter':
-              rlu_common.float_tensor_feature(3),
-          'sensors_gyro':
-              rlu_common.float_tensor_feature(3),
-          'sensors_touch':
-              rlu_common.float_tensor_feature(4),
-          'egocentric_camera':
-              tfds.features.Image(
-                  shape=(64, 64, 3), dtype=np.uint8, encoding_format='png'),
+          'joints_pos': rlu_common.float_tensor_feature(30),
+          'joints_vel': rlu_common.float_tensor_feature(30),
+          'tendons_pos': rlu_common.float_tensor_feature(8),
+          'tendons_vel': rlu_common.float_tensor_feature(8),
+          'appendages_pos': rlu_common.float_tensor_feature(15),
+          'world_zaxis': rlu_common.float_tensor_feature(3),
+          'sensors_accelerometer': rlu_common.float_tensor_feature(3),
+          'sensors_velocimeter': rlu_common.float_tensor_feature(3),
+          'sensors_gyro': rlu_common.float_tensor_feature(3),
+          'sensors_touch': rlu_common.float_tensor_feature(4),
+          'egocentric_camera': tfds.features.Image(
+              shape=(64, 64, 3), dtype=np.uint8, encoding_format='png'
+          ),
       }
       action_features = tfds.features.Tensor(shape=(38,), dtype=np.float32)
 
     return tfds.features.FeaturesDict({
-        'steps':
-            tfds.features.Dataset({
-                'observation': {
-                    'walker': walker_features,
-                },
-                'action': action_features,
-                'reward': np.float32,
-                'is_terminal': np.bool_,
-                'is_first': np.bool_,
-                'is_last': np.bool_,
-                'discount': np.float32,
-            }),
-        'episode_id':
-            np.int64,
-        'timestamp':
-            np.int64,
+        'steps': tfds.features.Dataset({
+            'observation': {
+                'walker': walker_features,
+            },
+            'action': action_features,
+            'reward': np.float32,
+            'is_terminal': np.bool_,
+            'is_first': np.bool_,
+            'is_last': np.bool_,
+            'discount': np.float32,
+        }),
+        'episode_id': np.int64,
+        'timestamp': np.int64,
     })
 
   def get_description(self):
@@ -243,41 +199,45 @@ class RluLocomotion(rlu_common.RLUBuilder):
   def num_shards(self):
     return self._SHARDS
 
-  def tf_example_to_step_ds(self,
-                            tf_example: tf.train.Example) -> Dict[str, Any]:
+  def tf_example_to_step_ds(
+      self, tf_example: tf.train.Example
+  ) -> Dict[str, Any]:
     """Create an episode from a TF example."""
     feature_description = _feature_description(self.builder_config.name)
 
     data = tf.io.parse_single_example(tf_example, feature_description)
     episode_length = tf.size(data['discount'])
-    is_first = tf.concat([[True], [False] * tf.ones(episode_length - 1)],
-                         axis=0)
+    is_first = tf.concat(
+        [[True], [False] * tf.ones(episode_length - 1)], axis=0
+    )
     is_last = tf.concat([[False] * tf.ones(episode_length - 1), [True]], axis=0)
     is_terminal = [False] * tf.ones(episode_length, tf.int64)
 
     # The data is in RSA alignment, we realign it to SAR to comply with the
     # RLDS standard.
     discount = data['discount'][1:]
-    if discount[-1] == 0.:
+    if discount[-1] == 0.0:
       is_terminal = tf.concat(
-          [[False] * tf.ones(episode_length - 1, tf.int64), [True]], axis=0)
+          [[False] * tf.ones(episode_length - 1, tf.int64), [True]], axis=0
+      )
       # If the episode ends in a terminal state, in the last step only the
       # observation has valid information (the terminal state).
-      discount = tf.concat([discount, [0.]], axis=0)
+      discount = tf.concat([discount, [0.0]], axis=0)
     else:
-      discount = tf.concat([discount, [1.]], axis=0)
+      discount = tf.concat([discount, [1.0]], axis=0)
 
-    reward = tf.concat([data['reward'][1:], [0.]], axis=0)
+    reward = tf.concat([data['reward'][1:], [0.0]], axis=0)
 
     obs_prefix = 'observation/walker/'
     obs = {}
     for k in feature_description:
       if k.startswith(obs_prefix):
-        new_k = k[len(obs_prefix):]
+        new_k = k[len(obs_prefix) :]
         if 'egocentric_camera' in k:
           obs[new_k] = tf.reshape(
               tf.io.decode_raw(data[k], out_type=tf.uint8),
-              (-1,) + (
+              (-1,)
+              + (
                   64,
                   64,
                   3,
@@ -287,15 +247,13 @@ class RluLocomotion(rlu_common.RLUBuilder):
           obs[new_k] = data[k]
     episode = {
         'steps': {
-            'observation': {
-                'walker': obs
-            },
+            'observation': {'walker': obs},
             'action': data['action'],
             'reward': reward,
             'discount': discount,
             'is_first': is_first,
             'is_last': is_last,
-            'is_terminal': is_terminal
+            'is_terminal': is_terminal,
         },
         'episode_id': data['episode_id'],
         'timestamp': data['timestamp'],
