@@ -46,17 +46,25 @@ def get_pwc_catalog_urls() -> Mapping[str, str]:
 @dataclasses.dataclass
 class DocUtilPaths:
   """Structure containing the utils paths."""
+
   # VisualizationDocUtil
   fig_base_path: Optional[tfds.typing.PathLike] = tfds.core.gcs_path(
-      'visualization/fig/')
-  fig_base_url: str = 'https://storage.googleapis.com/tfds-data/visualization/fig/'
+      'visualization/fig/'
+  )
+  fig_base_url: str = (
+      'https://storage.googleapis.com/tfds-data/visualization/fig/'
+  )
   # DataframeDocUtil
   df_base_path: Optional[tfds.typing.PathLike] = tfds.core.gcs_path(
-      'visualization/dataframe')
-  df_base_url: str = 'https://storage.googleapis.com/tfds-data/visualization/dataframe/'
+      'visualization/dataframe'
+  )
+  df_base_url: str = (
+      'https://storage.googleapis.com/tfds-data/visualization/dataframe/'
+  )
   # NightlyDocUtil
   nightly_path: Optional[tfds.typing.PathLike] = tfds.core.utils.tfds_path(
-      'stable_versions.txt')
+      'stable_versions.txt'
+  )
 
 
 class VisualizationDocUtil(object):
@@ -157,9 +165,11 @@ class DataframeDocUtil(object):
 def _split_full_name(full_name: str) -> Tuple[str, str, str]:
   """Extracts the `(ds name, config, version)` from the full_name."""
   if not tfds.core.load.is_full_name(full_name):
-    raise ValueError(f'Parsing builder name string {full_name} failed.'
-                     'The builder name string must be of the following format:'
-                     '`dataset_name[/config_name]/version`')
+    raise ValueError(
+        f'Parsing builder name string {full_name} failed.'
+        'The builder name string must be of the following format:'
+        '`dataset_name[/config_name]/version`'
+    )
   ds_name, *optional_config, version = full_name.split('/')
   assert len(optional_config) <= 1
   config = next(iter(optional_config)) if optional_config else ''
@@ -168,8 +178,11 @@ def _split_full_name(full_name: str) -> Tuple[str, str, str]:
 
 def _full_names_to_dict(full_names: List[str]) -> FullNamesDict:
   """Creates the dict `d['dataset']['config']['version']`."""
-  full_names_dict = collections.defaultdict(lambda: collections.defaultdict(  # pylint: disable=g-long-lambda
-      lambda: collections.defaultdict(type(None))))
+  full_names_dict = collections.defaultdict(
+      lambda: collections.defaultdict(  # pylint: disable=g-long-lambda
+          lambda: collections.defaultdict(type(None))
+      )
+  )
   for full_name in full_names:
     ds_name, config, version = _split_full_name(full_name)
     full_names_dict[ds_name][config][version]  # pylint: disable=pointless-statement
@@ -181,8 +194,11 @@ def _build_nightly_dict(
     stable_version_ds: FullNamesDict,
 ) -> NightlyDict:
   """Computes the nightly dict from the registered and stable dict."""
-  nightly_ds = collections.defaultdict(lambda: collections.defaultdict(  # pylint: disable=g-long-lambda
-      lambda: collections.defaultdict(bool)))
+  nightly_ds = collections.defaultdict(
+      lambda: collections.defaultdict(  # pylint: disable=g-long-lambda
+          lambda: collections.defaultdict(bool)
+      )
+  )
   for dataset in registered_ds:
     if dataset in stable_version_ds:
       for config in registered_ds[dataset]:
@@ -275,7 +291,8 @@ class NightlyDocUtil(object):
 
   icon = (
       '<span class="material-icons" '
-      'title="Available only in the tfds-nightly package">nights_stay</span>')
+      'title="Available only in the tfds-nightly package">nights_stay</span>'
+  )
 
 
 def format_homepage_url(homepage):
