@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,8 +22,13 @@ from tensorflow_datasets.structured import genomics_ood
 
 _FAKE_DATA_FILE = os.path.join(
     os.path.normpath(os.path.dirname(__file__) + '/../../'),
-    'tensorflow_datasets', 'testing', 'test_data', 'fake_examples',
-    'genomics_ood', 'genomics_ood.zip')
+    'tensorflow_datasets',
+    'testing',
+    'test_data',
+    'fake_examples',
+    'genomics_ood',
+    'genomics_ood.zip',
+)
 
 
 class GenomicsOodTest(tfds.testing.DatasetBuilderTestCase):
