@@ -42,16 +42,20 @@ doi = {10.18653/v1/D15-1135}
 
 class DolphinNumberWord(tfds.core.GeneratorBasedBuilder):
   """DatasetBuilder for dolphin_number_word problem dataset."""
+
   __count__ = 0
 
   VERSION = tfds.core.Version('0.0.2')
   RELEASE_NOTES = {
       '0.0.1': 'Initial release.',
-      '0.0.2': 'RaggedTensor fix. Equations and Sources represented as a single'
-               'string with components delimited by spaces',
-      '0.0.3':
+      '0.0.2': (
+          'RaggedTensor fix. Equations and Sources represented as a single'
+          'string with components delimited by spaces'
+      ),
+      '0.0.3': (
           'Reintroduced logic to handle edge-case involving examples without '
           'sources.'
+      ),
   }
 
   def _info(self) -> tfds.core.DatasetInfo:
@@ -69,7 +73,9 @@ class DolphinNumberWord(tfds.core.GeneratorBasedBuilder):
             'ans': tfds.features.Text(),
         }),
         supervised_keys=('text', 'ans'),  # Alternatively text, ans.
-        homepage='https://www.microsoft.com/en-us/research/project/sigmadolphin-2/',
+        homepage=(
+            'https://www.microsoft.com/en-us/research/project/sigmadolphin-2/'
+        ),
         citation=_CITATION,
     )
 
