@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,14 +21,15 @@ from tensorflow_datasets.text import wikipedia
 
 class WikipediaTest(testing.DatasetBuilderTestCase):
   """Test Wikipedia Dataset generation on fake dataset."""
+
   DATASET_CLASS = wikipedia.Wikipedia
-  BUILDER_CONFIG_NAMES_TO_TEST = ["20201201.en"]
+  BUILDER_CONFIG_NAMES_TO_TEST = ["20220620.en"]
 
   # url_checksums are read from `dumpstatus.json`
   # Modify dumpstatus.json if `date` is not `20200301`
   DL_EXTRACT_RESULT = {
       "info": "dumpstatus.json",
-      "xml": ["enwiki_fake.xml.bz2", "enwiki_fake2.xml.bz2"]
+      "xml": ["enwiki_fake.xml.bz2", "enwiki_fake2.xml.bz2"],
   }
 
   SPLITS = {
