@@ -22,8 +22,10 @@ from tensorflow_datasets.core.utils.lazy_imports_utils import tensorflow as tf
 import tensorflow_datasets.public_api as tfds
 
 UCF_101_URL = 'https://storage.googleapis.com/thumos14_files/UCF101_videos.zip'
-SPLITS_URL = ('https://www.crcv.ucf.edu/data/UCF101/'
-              'UCF101TrainTestSplits-RecognitionTask.zip')
+SPLITS_URL = (
+    'https://www.crcv.ucf.edu/data/UCF101/'
+    'UCF101TrainTestSplits-RecognitionTask.zip'
+)
 
 _CITATION = """\
 @article{DBLP:journals/corr/abs-1212-0402,
@@ -48,7 +50,7 @@ _LABELS_FNAME = 'video/ucf101_labels.txt'
 
 
 class Ucf101Config(tfds.core.BuilderConfig):
-  """"Configuration for UCF101 split and possible video rescaling."""
+  """ "Configuration for UCF101 split and possible video rescaling."""
 
   def __init__(self, *, split_number, width=None, height=None, **kwargs):
     """The parameters specifying how the dataset will be processed.
@@ -76,7 +78,8 @@ class Ucf101Config(tfds.core.BuilderConfig):
     self.height = height
     if split_number not in (1, 2, 3):
       raise ValueError(
-          'Unknown split number {}, should be 1, 2 or 3'.format(split_number))
+          'Unknown split number {}, should be 1, 2 or 3'.format(split_number)
+      )
     self.split_number = split_number
 
 
@@ -122,23 +125,29 @@ class Ucf101(tfds.core.GeneratorBasedBuilder):
     if self.builder_config.width is not None:
       if self.builder_config.height is None:
         raise ValueError('Provide either both height and width or none.')
-      ffmpeg_extra_args = ('-vf',
-                           'scale={}x{}'.format(self.builder_config.height,
-                                                self.builder_config.width))
+      ffmpeg_extra_args = (
+          '-vf',
+          'scale={}x{}'.format(
+              self.builder_config.height, self.builder_config.width
+          ),
+      )
     else:
       ffmpeg_extra_args = []
 
-    video_shape = (None, self.builder_config.height, self.builder_config.width,
-                   3)
+    video_shape = (
+        None,
+        self.builder_config.height,
+        self.builder_config.width,
+        3,
+    )
     labels_names_file = tfds.core.tfds_path(_LABELS_FNAME)
     features = tfds.features.FeaturesDict({
-        'video':
-            tfds.features.Video(
-                video_shape,
-                ffmpeg_extra_args=ffmpeg_extra_args,
-                encoding_format='jpeg'),  # pytype: disable=wrong-arg-types  # gen-stub-imports
-        'label':
-            tfds.features.ClassLabel(names_file=labels_names_file),
+        'video': tfds.features.Video(
+            video_shape,
+            ffmpeg_extra_args=ffmpeg_extra_args,
+            encoding_format='jpeg',
+        ),  # pytype: disable=wrong-arg-types  # gen-stub-imports
+        'label': tfds.features.ClassLabel(names_file=labels_names_file),
     })
     return tfds.core.DatasetInfo(
         builder=self,
@@ -161,25 +170,23 @@ class Ucf101(tfds.core.GeneratorBasedBuilder):
         tfds.core.SplitGenerator(
             name=tfds.Split.TRAIN,
             gen_kwargs={
-                'videos_dir':
-                    downloaded_urls['videos'],
-                'splits_dir':
-                    downloaded_urls['splits'],
-                'data_list':
-                    '{}/trainlist{:02d}.txt'.format(
-                        splits_folder, self.builder_config.split_number),
-            }),
+                'videos_dir': downloaded_urls['videos'],
+                'splits_dir': downloaded_urls['splits'],
+                'data_list': '{}/trainlist{:02d}.txt'.format(
+                    splits_folder, self.builder_config.split_number
+                ),
+            },
+        ),
         tfds.core.SplitGenerator(
             name=tfds.Split.TEST,
             gen_kwargs={
-                'videos_dir':
-                    downloaded_urls['videos'],
-                'splits_dir':
-                    downloaded_urls['splits'],
-                'data_list':
-                    '{}/testlist{:02d}.txt'.format(
-                        splits_folder, self.builder_config.split_number),
-            }),
+                'videos_dir': downloaded_urls['videos'],
+                'splits_dir': downloaded_urls['splits'],
+                'data_list': '{}/testlist{:02d}.txt'.format(
+                    splits_folder, self.builder_config.split_number
+                ),
+            },
+        ),
     ]
 
   def _generate_examples(self, videos_dir, splits_dir, data_list):
